@@ -6,6 +6,7 @@ from airflow_commons.utils.mysql.mysql_utils import upsert, get_db_engine
 from airflow_commons.utils.mysql.mysql_utils import update as update_util
 from airflow_commons.utils.mysql.sql_utils import get_delete_sql
 from airflow_commons.utils.mysql.sql_utils import get_select_all_sql
+from airflow_commons.utils.mysql.sql_utils import get_select_sql
 from airflow_commons.utils.mysql.sql_utils import get_row_count_sql
 import pandas as pd
 
@@ -123,6 +124,54 @@ def select_all(
     return result
 
 
+def select(
+    username: str,
+    password: str,
+    host: str,
+    db_name: str,
+    table_name: str,
+    column_names: list,
+    where_statement_file: str,
+    where_statement_params: dict = None,
+    return_type: str = "resultProxy",
+):
+    """
+    Runs a select query on given table and returns the rows that conform where condition
+
+    :param username: database username
+    :param password: database password
+    :param host: database host
+    :param db_name: database name
+    :param table_name: database table name
+    :param column_name: column name from the table
+    :param where_statement_params: relative location of where statement sql file
+    :param where_statement_file: parameters of where statements
+    :param return_type: parameter which determines return type
+    :return: iterable ResultProxy object that stores results of the select query
+    """
+    engine = get_db_engine(username, password, host, db_name)
+    connection = engine.raw_connection()
+    if where_statement_params is None:
+        where_statement_params = dict()
+    where_statement = read_sql(sql_file=where_statement_file, **where_statement_params)
+    sql = get_select_sql(
+        table_name=table_name,
+        column_names=column_names,
+        where_statement=where_statement,
+    )
+    if return_type == "dataframe":
+        result = pd.read_sql(sql, connection)
+    else:
+        cursor = connection.cursor()
+        cursor.execute(sql)
+        result = cursor.fetchall()
+        connection.commit()
+        connection.close()
+    LOGGER.info(f"The below sql statement is executed \n {sql}")
+    LOGGER.info(f"Number of records retrieved = {str(len(result))}")
+    return result
+
+
 def get_row_count(
     username: str,
     password: str,
